==> igniteui-angular-charts-18.1.0.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afi != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afi != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afi == null) {
                if (this.ad != null) {
                    c.afi = this.ad;
                }
                else {
                    c.afi = c.dataChart.z6;
                }
            }
        }
        else {
            if (c.afi != null) {
                this.ad = c.afi;
                c.afi = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };

==> igniteui-angular-charts-18.1.1.tgz: package/esm5/lib/DataPieChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var DataPieChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataPieChartToolbarProvider, _super);
    function DataPieChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    DataPieChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afu != null;
                }
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "AngleAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afu != null);
                break;
        }
    };
    DataPieChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afu == null) {
                if (this.ad != null) {
                    c.afu = this.ad;
                }
                else {
                    c.afu = c.dataChart.z6;
                }
            }
        }
        else {
            if (c.afu != null) {
                this.ad = c.afu;
                c.afu = null;
            }
        }
    };
    DataPieChartToolbarProvider.$t = markType(DataPieChartToolbarProvider, 'DataPieChartToolbarProvider', DomainChartToolbarProvider.$);
    return DataPieChartToolbarProvider;
}(DomainChartToolbarProvider));
export { DataPieChartToolbarProvider };
